Tags are a way to classify the site content in an unordered fashion. It's a
powerful way to group entities of any type.

When viewing an entity which can be tagged (look `here`_ to see which types can
be tagged), you should see the tags box appear displaying tags applied to this
entity (if not, check your `user preferences`_, and permitting to handle
them. 

To add a tag, click on the `add tags` link in the box to get the add tag
field. As you type in this field, you should see appear existing tags matching
characters you types if any. You can then:

* select the desired tag by clicking on it
* type *TAB* to complete your entry
* finish typing the tag name if it doesn't exist yet
* type *ESC* to make disappear the drop down list

Eventually you can add multiple tags by separating them with a comma.

Then type *Enter* or click the `validate` link to add the tag, or click the
`cancel` link to cancel the operation.

To remove a tag, simply click on the `[-]` sign to the left of it.

Note that if you wish, you can change your preferencece to display them in a
component in the top or in the bottom of the page instead of the box. Provided
functionalities are the same, except for quick link to remove a tag.


.. _`here`: eetype/Tag?vid=eschema
.. _`user preferences`: myprefs